###########
Django Cast
###########

Welcome to the Django Cast documentation! Django Cast is a blogging and podcasting
package for `Django <https://https://www.djangoproject.com/>`_ based on `Wagtail <https://wagtail.org/>`_.

This documentation is still in development and there are a lot of blanks to
fill since Django Cast switched to Wagtail.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   contributing
   features
   tests
   backup
   howto/index
   release
   releases/index
   models
   context-processors
   settings
